@@ -27,7 +27,7 @@
 #define LLVM_HAS_ATOMICS 1
 
 /* Host triple LLVM will be executed on */
-#define LLVM_HOST_TRIPLE "powerpc64-unknown-linux-gnu"
+#define LLVM_HOST_TRIPLE "powerpc64le-unknown-linux-gnu"
 
 /* LLVM architecture name for the native architecture, if available */
 #define LLVM_NATIVE_ARCH AArch64
@@ -72,7 +72,7 @@
 #define LLVM_VERSION_PATCH 0
 
 /* LLVM version string */
-#define LLVM_VERSION_STRING "13.0.0-rust-1.58.1-stable"
+#define LLVM_VERSION_STRING "13.0.0-rust-1.59.0-stable"
 
 /* Whether LLVM records statistics for use with GetStatistics(),
  * PrintStatistics() or PrintStatisticsJSON()
